16.143. cdist-type__user(7) — cdist 4.10.11 documentation

# 16.143. cdist-type__user(7)

## 16.143.1. NAME

cdist-type__user - Manage users

## 16.143.2. DESCRIPTION

This cdist type allows you to create or modify users on the target.

## 16.143.3. REQUIRED PARAMETERS

None.

## 16.143.4. OPTIONAL PARAMETERS

state
  absent or present, defaults to present
comment
  see usermod(8)
home
  see above
gid
  see above
password
  see above
shell
  see above
uid
  see above

## 16.143.5. BOOLEAN PARAMETERS

system
  see useradd(8), apply only on user create
create-home
  see useradd(8), apply only on user create
remove-home
  see userdel(8), apply only on user delete

## 16.143.6. MESSAGES

mod
  User is modified
add
  New user added
userdel -r
  If user was deleted with homedir
userdel
  If user was deleted (keeping homedir)

## 16.143.7. EXAMPLES

    # Create user account for foobar with operating system default settings
    __user foobar

    # Same but with a different shell
    __user foobar --shell /bin/zsh

    # Same but for a system account
    __user foobar --system

    # Set explicit uid and home
    __user foobar --uid 1001 --shell /bin/zsh --home /home/foobar

    # Drop user if exists
    __user foobar --state absent

## 16.143.8. SEE ALSO

pw(8), usermod(8)

## 16.143.9. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 16.143.10. COPYING

Copyright (C) 2011 Steven Armstrong. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.